==> media_service-tomato-20190604.082125-1-sources.jar: com/jz/jar/media/repository/TomatoImageTextRepository.java <==
package com.jz.jar.media.repository;

import java.util.Collection;
import java.util.List;

import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Repository;

import com.jz.jar.media.enums.AuditStatus;
import com.jz.jooq.media.Tables;
import com.jz.jooq.media.tables.pojos.TomatoImageText;

@Lazy
@Repository
public class TomatoImageTextRepository extends MediaBaseRepository {

	private static final com.jz.jooq.media.tables.TomatoImageText IT = Tables.TOMATO_IMAGE_TEXT;
	private static final com.jz.jooq.media.tables.TomatoPlaylistImageText PI = Tables.TOMATO_PLAYLIST_IMAGE_TEXT;

	public List<TomatoImageText> findOnlineImageText(Collection<String> iids) {
		return mediaCtx.selectFrom(IT).where(IT.ID.in(iids).and(IT.STATUS.eq(AuditStatus.online.getCode())))
				.fetchInto(TomatoImageText.class);
	}

	public TomatoImageText getOnlineImageText(String iid) {
		return mediaCtx.selectFrom(IT).where(IT.ID.eq(iid).and(IT.STATUS.eq(AuditStatus.online.getCode())))
				.fetchAnyInto(TomatoImageText.class);
	}

	public List<String> findImageTextIdForPlaylist(String pid) {
		return mediaCtx.select(PI.IID).from(PI).where(PI.PID.eq(pid)).orderBy(PI.SEQ.asc()).fetchInto(String.class);
	}

	public int countImageTextIdForPlaylist(String pid) {
		return mediaCtx.fetchCount(PI, PI.PID.eq(pid));
	}

	public List<String> findImageTextIdForPlaylist(String pid, int start, int size) {
		return mediaCtx.select(PI.IID).from(PI).where(PI.PID.eq(pid)).orderBy(PI.SEQ.asc()).limit(start, size)
				.fetchInto(String.class);
	}

	public boolean isExistImageTextForPlaylist(String pid, String iid) {
		return mediaCtx.fetchExists(PI, PI.PID.eq(pid).and(PI.IID.eq(iid)));
	}
}

==> media_service-tomato-20190604.085439-4-sources.jar: com/jz/jar/media/repository/TomatoImageTextRepository.java <==
package com.jz.jar.media.repository;

import java.util.Collection;
import java.util.List;

import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Repository;

import com.jz.jar.media.enums.AuditStatus;
import com.jz.jooq.media.Tables;
import com.jz.jooq.media.tables.pojos.TomatoImageText;

@Lazy
@Repository
public class TomatoImageTextRepository extends MediaBaseRepository {

	private static final com.jz.jooq.media.tables.TomatoImageText IT = Tables.TOMATO_IMAGE_TEXT;
	private static final com.jz.jooq.media.tables.TomatoPlaylistImageText PI = Tables.TOMATO_PLAYLIST_IMAGE_TEXT;

	public List<TomatoImageText> findOnlineImageText(Collection<String> iids) {
		return mediaCtx.select(IT.ID, IT.NAME, IT.WATCH_CNT).from(IT)
				.where(IT.ID.in(iids).and(IT.STATUS.eq(AuditStatus.online.getCode()))).fetchInto(TomatoImageText.class);
	}

	public TomatoImageText getOnlineImageText(String iid) {
		return mediaCtx.selectFrom(IT).where(IT.ID.eq(iid).and(IT.STATUS.eq(AuditStatus.online.getCode())))
				.fetchAnyInto(TomatoImageText.class);
	}

	public List<String> findImageTextIdForPlaylist(String pid) {
		return mediaCtx.select(PI.IID).from(PI).where(PI.PID.eq(pid)).orderBy(PI.SEQ.asc()).fetchInto(String.class);
	}

	public int countImageTextIdForPlaylist(String pid) {
		return mediaCtx.fetchCount(PI, PI.PID.eq(pid));
	}

	public List<String> findImageTextIdForPlaylist(String pid, int start, int size) {
		return mediaCtx.select(PI.IID).from(PI).where(PI.PID.eq(pid)).orderBy(PI.SEQ.asc()).limit(start, size)
				.fetchInto(String.class);
	}

	public boolean isExistImageTextForPlaylist(String pid, String iid) {
		return mediaCtx.fetchExists(PI, PI.PID.eq(pid).and(PI.IID.eq(iid)));
	}
}
